Function muse_channel::new_channel_function

source ·
pub fn new_channel_function() -> RustFunction
Returns a function that creates a new channel.

When called with no arguments, this function returns an unbounded channel.

When called with one argument, it is converted to an integer and used as the bounds of a bounded channel.