Struct muse_channel::ValueReceiver

source ·
pub struct ValueReceiver { /* private fields */ }
A receiver of [RootedValue]s that are sent by one or more ValueSenders.

Implementations

source

impl ValueReceiver

source

pub fn recv(&self) -> Option<RootedValue>

Reads the oldest [RootedValue] from the channel, blocking the current thread until a value is received.

Returns None if all ValueSenders have been dropped before a value is received.

source

pub fn recv_async(&self) -> RecvAsync<'_>

Reads the oldest [RootedValue] from the channel, blocking the current task until a value is received.

Returns None if all ValueSenders have been dropped before a value is received.

source

pub fn senders(&self) -> usize

Returns the number of associated ValueSenders that have not been dropped.

source

pub fn is_disconnected(&self) -> bool

Returns true if all associated ValueSenders have been dropped.