Struct muse_channel::ValueSender

source ·
pub struct ValueSender { /* private fields */ }
A sender of [RootedValue]s to be received by one or more ValueReceivers.

Implementations

source

impl ValueSender

source

pub fn send(&self, value: RootedValue) -> Result<(), RootedValue>

Pushes value to the queue for ValueReceivers to read from.

If this sender is for a bounded channel and the channel is full, this function will block the current thread until space is available or it is disconnected. Use send_async(value).await in async code instead to ensure proper interaction with the async runtime.

Errors

This function returns value if the channel is disconnected before value can be pushed.

source

pub fn try_send(&self, value: RootedValue) -> Result<(), TrySendError>

Tries to push value to the queue for ValueReceivers to read from.

This function is safe to be invoked from both async and non-async code.

Errors
source

pub fn send_async(&self, value: RootedValue) -> SendAsync<'_>

Pushes value to the queue for ValueReceivers to read from.

If this sender is for a bounded channel and the channel is full, this function will block the current task until space is available or it is disconnected.

Errors

This function returns value if the channel is disconnected before value can be pushed.

source

pub fn receivers(&self) -> usize

Returns the number of associated ValueReceivers that have not been dropped.

source

pub fn is_disconnected(&self) -> bool

Returns true if all associated ValueReceivers have been dropped.