Struct muse_channel::ValueSender
source · pub struct ValueSender { /* private fields */ }Expand description
A sender of [RootedValue]s to be received by one or more ValueReceivers.
Implementations
sourceimpl ValueSender
impl ValueSender
sourcepub fn send(&self, value: RootedValue) -> Result<(), RootedValue>
pub fn send(&self, value: RootedValue) -> Result<(), RootedValue>
Pushes value to the queue for ValueReceivers to read from.
If this sender is for a bounded channel and the channel is full, this
function will block the current thread until space is available or it is
disconnected. Use send_async(value).await in async
code instead to ensure proper interaction with the async runtime.
Errors
This function returns value if the channel is disconnected before
value can be pushed.
sourcepub fn try_send(&self, value: RootedValue) -> Result<(), TrySendError>
pub fn try_send(&self, value: RootedValue) -> Result<(), TrySendError>
Tries to push value to the queue for ValueReceivers to read from.
This function is safe to be invoked from both async and non-async code.
Errors
TrySendError::Disconnected: All associatedValueReceivers have been dropped.TrySendError::Full: The value cannot be pushed due to the channel being full.
sourcepub fn send_async(&self, value: RootedValue) -> SendAsync<'_> ⓘ
pub fn send_async(&self, value: RootedValue) -> SendAsync<'_> ⓘ
Pushes value to the queue for ValueReceivers to read from.
If this sender is for a bounded channel and the channel is full, this function will block the current task until space is available or it is disconnected.
Errors
This function returns value if the channel is disconnected before
value can be pushed.
sourcepub fn receivers(&self) -> usize
pub fn receivers(&self) -> usize
Returns the number of associated ValueReceivers that have not been
dropped.
sourcepub fn is_disconnected(&self) -> bool
pub fn is_disconnected(&self) -> bool
Returns true if all associated ValueReceivers have been dropped.